@@ -248,7 +248,7 @@ class Mamba2(nn.Module):
                         n_heads=n_heads,
                         chunk_size=chunk_size,
                         device=device
-                    ) if cuda_mamba2 is None else
+                    ) if True else
                     cuda_mamba2(
                         d_model=emb_dim,
                         d_state=self.d_state,
